@@ -4,7 +4,7 @@ import warnings
 from fastf1.api import Cache
 from fastf1.version import __version__
 
-base_url = 'http://ergast.com/api/f1'
+base_url = 'https://ergast.com/api/f1'
 _headers = {'User-Agent': f'FastF1/{__version__}'}
 
 
@@ -33,6 +33,12 @@ def fetch_season(year):
 
 
 def fetch_weekend(year, gp):
+    warnings.warn(
+        "`fetch_weekend()` is deprecated and will be"
+        "removed without a direct replacement in a "
+        "future version.",
+        FutureWarning
+    )
     url = f"{base_url}/{year}/{gp}.json"
     data = _parse_ergast(_parse_json_response(
         Cache.requests_get(url, headers=_headers)
