@@ -24,6 +24,7 @@ and colors which are provided below.
 .. note:: Plotting related functionality is likely to change in a future
     release.
 """
+from typing import Dict
 
 import pandas as pd
 import numpy as np
@@ -99,23 +100,23 @@ DRIVER_COLORS = {
         "valtteri bottas": "#900000",
         "zhou guanyu": "#500000",
 
-        "pierre gasly": "#2b4562",
+        "nyck de vries": "#2b4562",
         "yuki tsunoda": "#356cac",
 
-        "fernando alonso": "#0090ff",
+        "pierre gasly": "#0090ff",
         "esteban ocon": "#70c2ff",
 
-        "sebastian vettel": "#006f62",
+        "fernando alonso": "#006f62",
         "lance stroll": "#25a617",
-        "nico hulkenberg": "#2f9b90",
+        "felipe drugovich": "#2f9b90",
 
         "charles leclerc": "#dc0000",
         "carlos sainz": "#ff8181",
 
         "kevin magnussen": "#ffffff",
-        "mick schumacher": "#cacaca",
+        "nico hulkenburg": "#cacaca",
 
-        "daniel ricciardo": "#ff8700",
+        "oscar piastri": "#ff8700",
         "lando norris": "#eeb370",
 
         "lewis hamilton": "#00d2be",
@@ -125,23 +126,22 @@ DRIVER_COLORS = {
         "sergio perez": "#716de2",
 
         "alexander albon": "#005aff",
-        "nicholas latifi": "#012564",
-    }
+        "logan sargeant": "#012564",
+}
 """Mapping of driver colors (hex color code) to driver names.
 (current season only)"""
 
-
-DRIVER_TRANSLATE = {'LEC': 'charles leclerc', 'SAI': 'carlos sainz',
-                    'VER': 'max verstappen', 'SER': 'sergio perez',
-                    'RIC': 'daniel ricciardo', 'NOR': 'lando norris',
-                    'ALO': 'fernando alonso', 'OCO': 'esteban ocon',
-                    'BOT': 'valtteri bottas', 'ZHO': 'zhou guanyu',
-                    'GAS': 'pierre gasly', 'TSU': 'yuki tsunoda',
-                    'MAG': 'kevin magnussen', 'MSC': 'mick schumacher',
-                    'VET': 'sebastian vettel', 'HUL': 'nico hulkenberg',
-                    'STR': 'lance stroll',
-                    'HAM': 'lewis hamilton', 'RUS': 'george russell',
-                    'ALB': 'alexander albon', 'LAT': 'nicholas latifi'}
+DRIVER_TRANSLATE: Dict[str, str] = {
+    'LEC': 'charles leclerc', 'SAI': 'carlos sainz',
+    'VER': 'max verstappen', 'PER': 'sergio perez',
+    'PIA': 'oscar piastri', 'NOR': 'lando norris',
+    'GAS': 'pierre gasly', 'OCO': 'esteban ocon',
+    'BOT': 'valtteri bottas', 'ZHO': 'zhou guanyu',
+    'DEV': 'nyck de vries', 'TSU': 'yuki tsunoda',
+    'MAG': 'kevin magnussen', 'HUL': 'nico hulkenburg',
+    'ALO': 'fernando alonso', 'STR': 'lance stroll', 'DRU': 'felipe drugovich',
+    'HAM': 'lewis hamilton', 'RUS': 'george russell',
+    'ALB': 'alexander albon', 'SAR': 'logan sargeant'}
 """Mapping of driver names to theirs respective abbreviations."""
 
 COLOR_PALETTE = ['#FF79C6', '#50FA7B', '#8BE9FD', '#BD93F9',
